--[[
/*******************************************************************************\
*                                                                               *
* NO2Injection.lua                                                              *
*                                                                               *
*********************************************************************************
* Licensed under the MIT or X11 License                                         *
*                                                                               *
* Copyright (c) 2014 Eisbearg                                                   *
*                                                                               *
* Permission is hereby granted, free of charge, to any person obtaining a copy  *
* of this software and associated documentation files (the "Software"), to deal *
* in the Software without restriction, including without limitation the rights  *
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell     *
* copies of the Software, and to permit persons to whom the Software is         *
* furnished to do so, subject to the following conditions:                      *
*                                                                               *
* The above copyright notice and this permission notice shall be included in    *
* all copies or substantial portions of the Software.                           *
*                                                                               *
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR    *
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,      *
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE   *
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER        *
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, *
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN     *
* THE SOFTWARE.                                                                 *
\*******************************************************************************/
--]]




local metadata = {
"NO2Injection",
"Specialization to give a little more power",
"Eisbearg",
"1.0.0",
"11.01.2014"
}




NO2Injection = {};


function NO2Injection.prerequisitesPresent(specializations)
    return true;
end;


function NO2Injection:load(xmlFile)
	self.toggleNO2Injection = SpecializationUtil.callSpecializationsFunction("toggleNO2Injection");
	self.NO2Injection = {};

	local name = getXMLString(xmlFile, "vehicle.name");
	if name == nil then
		name = getXMLString(xmlFile, "vehicle.name.en");
	end;
	if name == nil then
		name = getXMLString(xmlFile, "vehicle.name.de");
	end;
	if name == nil then
		name = getXMLString(xmlFile, "vehicle.name.es");
	end;
	if name == nil then
		name = getXMLString(xmlFile, "vehicle.name.fr");
	end;
	if name == nil then
		name = getXMLString(xmlFile, "vehicle.name.pt");
	end;
	if name == nil then
		name = getXMLString(xmlFile, "vehicle.name.ru");
	end;
	if name == nil then
		name = "UnknownVehicle";
	end;
	print("--- inserting "..metadata[1].." in vehicle "..name);

	self.NO2Injection.id = metadata[1];
	self.NO2Injection.name = name;
	self.NO2Injection.torqueDefault = self.motor.maxMotorTorque;
	--self.motor.maxTorque
	print(self.motor.torqueScale);
	self.NO2Injection.torqueActive = tonumber(self.motor.maxMotorTorque) * 1.5;
	self.NO2Injection.move = false;
	self.NO2Injection.helpText = true;
	
	for _,v in pairs(self.motor) do
                print (_);
                print(v);
                print ("---------");
				end;
	for _,v in pairs(self.motor) do
                print (_);
                print(v);
                print ("---------");
				end;
end;


function NO2Injection:delete()
end;


function NO2Injection:mouseEvent(posX, posY, isDown, isUp, button)
end;


function NO2Injection:keyEvent(unicode, sym, modifier, isDown)
end;


function NO2Injection:update(dt)
	if self:getIsActiveForInput(true) then
		if InputBinding.isPressed(InputBinding[self.NO2Injection.id]) then
			--print("NO2Injection requested"..self.NO2Injection.name);
			self:toggleNO2Injection(true); 
		end;
	end;
	
	if self:getIsActive() then
		if self.NO2Injection.move then
			self.NO2Injection.move = false;
			print("NO2 injecting "..self.NO2Injection.name);
			self.motor.maxTorque = self.NO2Injection.torqueActive;
		else
			self.motor.maxTorque = self.NO2Injection.torqueDefault;
		end;
	end;
	--[[
			local curRot = {getRotation(part.index)};
			local newRot = Utils.getMovedLimitedValues(curRot, part.rotMax, part.rotMin, 3, part.moveTime, dt, not part.toMax);
			local curTrans = {getTranslation(part.index)};
			local newTrans = Utils.getMovedLimitedValues(curTrans, part.transMax, part.transMin, 3, part.moveTime, dt, not part.toMax);
	--]]
end;


function NO2Injection:updateTick(dt)
end;


function NO2Injection:draw()
	if self:getIsActiveForInput(true) then
		if self.NO2Injection.helpText then
			g_currentMission:addHelpButtonText(g_i18n:getText(self.NO2Injection.id), InputBinding[self.NO2Injection.id]);
		end;
	end;
end;


function NO2Injection:toggleNO2Injection(state, nes)
	NO2InjectionEvent.sendEvent(self, state, nes);
	self.NO2Injection.move = true;
end;


function NO2Injection:readStream(streamId, connection)
	local state = streamReadBool(streamId);
	self:toggleNO2Injection(state, true);
end;
		
	
function NO2Injection:writeStream(streamId, connection)
	streamWriteBool(streamId, self.NO2Injection.move);
end;


function NO2Injection:printDirection()
end;




NO2InjectionEvent = {};
NO2InjectionEvent_mt = Class(NO2InjectionEvent, Event);
InitEventClass(NO2InjectionEvent, "NO2InjectionEvent");


function NO2InjectionEvent:emptyNew()
    local self = Event:new(NO2InjectionEvent_mt);
    self.className="NO2InjectionEvent";
    return self;
end;


function NO2InjectionEvent:new(object, state)
		local self = NO2InjectionEvent:emptyNew()
		self.object = object;
		self.state = state;
		return self;
end;


function NO2InjectionEvent:readStream(streamId, connection)
    self.object = networkGetObject(streamReadInt32(streamId));
    self.state = streamReadBool(streamId);
    self:run(connection);
end;


function NO2InjectionEvent:writeStream(streamId, connection)
	streamWriteInt32(streamId, networkGetObjectId(self.object));
	streamWriteBool(streamId, self.state);
end;


function NO2InjectionEvent:run(connection)
	self.object:toggleNO2Injection(self.state, true);
	if not connection:getIsServer() then
		g_server:broadcastEvent(NO2InjectionEvent:new(self.object, self.state), nil, connection, self.object);
	end;	
end;


function NO2InjectionEvent.sendEvent(vehicle, state, nes)
	if nes == nil or nes == false then
		if g_server ~= nil then
			g_server:broadcastEvent(NO2InjectionEvent:new(vehicle, state), nil, nil, vehicle);
		else
			g_client:getServerConnection():sendEvent(NO2InjectionEvent:new(vehicle, state));
		end;
	end;
end;
